Limitations
===========

There are two reasons stuff isn't implemented in ``alchimia``.

First, because we haven't gotten there yet. For these items you should
:doc:`file bugs or send pull requests </contributing>`.

Second, some items can't be implemented because of limitations in SQLAlchemy,
there's almost always a workaround though.

* :doc:`Table creation </ddl>`
